Weibull and Gumbel kernel related functions are presented. Weibull and Gumbel present estimated values and plot.Weibull and plot.Gumbel plot the densities. While mseweibull and msegumbel calculate the Mean Squared Error (MSE).
Density Estimation by Extreme Value Distributions
Salha, R. B., El Shekh Ahmed, H. I., & Alhoubi, I. M. 2014. Hazard Rate Function Estimation Using Weibull Kernel. Open Journal of Statistics 4 (08), 650-661.
Khan, J. A.; Akbar, A. Density Estimation by Gumbel Kernel. 2020. Working paper, Department of Statistics, Bahauddin Zakariya University, Multan, Pakistan.
Useful links: